==> primeng-2.0.3.jar: META-INF/resources/webjars/primeng/2.0.3/components/slidemenu/slidemenu.d.ts <==
import { ElementRef, AfterViewInit, OnDestroy, Renderer } from '@angular/core';
import { DomHandler } from '../dom/domhandler';
import { MenuItem } from '../common/api';
import { Router } from '@angular/router';
export declare class SlideMenuSub implements OnDestroy {
    slideMenu: SlideMenu;
    router: Router;
    item: MenuItem;
    root: boolean;
    backLabel: string;
    menuWidth: string;
    effectDuration: any;
    easing: string;
    constructor(slideMenu: SlideMenu, router: Router);
    activeItem: any;
    itemClick(event: any, item: MenuItem, listitem: any): void;
    ngOnDestroy(): void;
}
export declare class SlideMenu implements AfterViewInit, OnDestroy {
    el: ElementRef;
    domHandler: DomHandler;
    renderer: Renderer;
    model: MenuItem[];
    popup: boolean;
    style: any;
    styleClass: string;
    menuWidth: number;
    viewportHeight: number;
    effectDuration: any;
    easing: string;
    backLabel: string;
    containerViewChild: ElementRef;
    backwardViewChild: ElementRef;
    container: HTMLDivElement;
    backwardElement: HTMLDivElement;
    documentClickListener: any;
    preventDocumentDefault: any;
    left: number;
    animating: boolean;
    viewportContentHeight: number;
    constructor(el: ElementRef, domHandler: DomHandler, renderer: Renderer);
    ngAfterViewInit(): void;
    toggle(event: any): void;
    show(event: any): void;
    hide(): void;
    unsubscribe(item: any): void;
    onClick(event: any): void;
    goBack(): void;
    ngOnDestroy(): void;
}
export declare class SlideMenuModule {
}

==> primeng-4.1.2.jar: META-INF/resources/webjars/primeng/4.1.2/components/slidemenu/slidemenu.d.ts <==
import { ElementRef, AfterViewInit, OnDestroy, Renderer2 } from '@angular/core';
import { DomHandler } from '../dom/domhandler';
import { MenuItem } from '../common/menuitem';
export declare class SlideMenuSub implements OnDestroy {
    slideMenu: SlideMenu;
    item: MenuItem;
    root: boolean;
    backLabel: string;
    menuWidth: string;
    effectDuration: any;
    easing: string;
    constructor(slideMenu: SlideMenu);
    activeItem: any;
    itemClick(event: any, item: MenuItem, listitem: any): void;
    ngOnDestroy(): void;
}
export declare class SlideMenu implements AfterViewInit, OnDestroy {
    el: ElementRef;
    domHandler: DomHandler;
    renderer: Renderer2;
    model: MenuItem[];
    popup: boolean;
    style: any;
    styleClass: string;
    menuWidth: number;
    viewportHeight: number;
    effectDuration: any;
    easing: string;
    backLabel: string;
    containerViewChild: ElementRef;
    backwardViewChild: ElementRef;
    slideMenuContentViewChild: ElementRef;
    container: HTMLDivElement;
    backwardElement: HTMLDivElement;
    slideMenuContentElement: HTMLDivElement;
    documentClickListener: any;
    preventDocumentDefault: any;
    left: number;
    animating: boolean;
    constructor(el: ElementRef, domHandler: DomHandler, renderer: Renderer2);
    ngAfterViewInit(): void;
    toggle(event: any): void;
    show(event: any): void;
    hide(): void;
    onClick(event: any): void;
    goBack(): void;
    ngOnDestroy(): void;
}
export declare class SlideMenuModule {
}
